nbxmpp.dispatcher_nb.Dispatcher

Package nbxmpp :: Module dispatcher_nb :: Class Dispatcher |
[hide private]
[frames] | no frames]

# Class Dispatcher

source code

Why is this here - I needed to redefine Dispatcher for BOSH and easiest way was to inherit original Dispatcher (now renamed to XMPPDispatcher). Trouble is that reference used to access dispatcher instance is in Client attribute named by __class__.__name__ of the dispatcher instance .. long story short:

I wrote following to avoid changing each client.Dispatcher.whatever() in xmpp

If having two kinds of dispatcher will go well, I will rewrite the dispatcher references in other scripts

Instance Methods | [hide private]
PlugIn(self, client_obj, after_SASL=False, old_features=None) | source code

Class Methods | [hide private]
get_instance(cls, *args, **kwargs) Factory Method for object creation | source code

Method Details | [hide private]

### PlugIn(self, client_obj, after_SASL=False, old_features=None) | source code

### get_instance(cls, *args, **kwargs) Class Method | source code
Factory Method for object creation Use this instead of directly initializing the class in order to make unit testing much easier.